import { ReactNode, RefObject, Dispatch, SetStateAction } from "react";
import { TableFilterState, FilterCondition } from "../types/FilterTypes";
import TableRow from "../types/TableRow";
import Cell from "../types/Cell";
import HeaderObject from "../types/HeaderObject";
import OnSortProps from "../types/OnSortProps";
import Theme from "../types/Theme";
import CellValue from "../types/CellValue";
export interface CellRegistryEntry {
    updateContent: (newValue: CellValue) => void;
}
interface TableContextType {
    allowAnimations?: boolean;
    cellRegistry?: Map<string, CellRegistryEntry>;
    cellUpdateFlash?: boolean;
    columnReordering: boolean;
    columnResizing: boolean;
    draggedHeaderRef: RefObject<HeaderObject | null>;
    editColumns?: boolean;
    expandIcon?: ReactNode;
    expandedRows: Set<string>;
    filters: TableFilterState;
    tableRows: TableRow[];
    forceUpdate: () => void;
    getBorderClass: (cell: Cell) => string;
    handleApplyFilter: (filter: FilterCondition) => void;
    handleClearFilter: (accessor: string) => void;
    handleClearAllFilters: () => void;
    handleMouseDown: (cell: Cell) => void;
    handleMouseOver: (cell: Cell) => void;
    headersRef: RefObject<HeaderObject[]>;
    hiddenColumns: Record<string, boolean>;
    hoveredHeaderRef: RefObject<HeaderObject | null>;
    isCopyFlashing: (cell: Cell) => boolean;
    isInitialFocusedCell: (cell: Cell) => boolean;
    isSelected: (cell: Cell) => boolean;
    isWarningFlashing: (cell: Cell) => boolean;
    mainBodyRef: RefObject<HTMLDivElement | null>;
    nextIcon: ReactNode;
    onCellEdit?: (props: any) => void;
    onColumnOrderChange?: (newHeaders: HeaderObject[]) => void;
    onSort: OnSortProps;
    onTableHeaderDragEnd: (newHeaders: HeaderObject[]) => void;
    pinnedLeftRef: RefObject<HTMLDivElement | null>;
    pinnedRightRef: RefObject<HTMLDivElement | null>;
    prevIcon: ReactNode;
    rowGrouping?: string[];
    rowHeight: number;
    rowIdAccessor: string;
    scrollbarWidth: number;
    selectColumns?: (columnIndices: number[], isShiftKey?: boolean) => void;
    selectableColumns: boolean;
    setExpandedRows: Dispatch<SetStateAction<Set<string>>>;
    setInitialFocusedCell: Dispatch<SetStateAction<Cell | null>>;
    setMainBodyWidth: Dispatch<SetStateAction<number>>;
    setPinnedLeftWidth: Dispatch<SetStateAction<number>>;
    setPinnedRightWidth: Dispatch<SetStateAction<number>>;
    setSelectedCells: Dispatch<SetStateAction<Set<string>>>;
    setSelectedColumns: Dispatch<SetStateAction<Set<number>>>;
    shouldPaginate: boolean;
    sortDownIcon: ReactNode;
    sortUpIcon: ReactNode;
    tableBodyContainerRef: RefObject<HTMLDivElement | null>;
    theme: Theme;
    useHoverRowBackground: boolean;
    useOddColumnBackground: boolean;
    useOddEvenRowBackground: boolean;
}
export declare const TableContext: import("react").Context<TableContextType | undefined>;
export declare const TableProvider: ({ children, value, }: {
    children: ReactNode;
    value: TableContextType;
}) => import("react/jsx-runtime").JSX.Element;
export declare const useTableContext: () => TableContextType;
export {};
